@@ -167,7 +167,10 @@ qcUI <- function(id) {
           tags$style(HTML('#qc-run{background-color:orange}')),
           ### summary method
           
-          uiOutput(ns("summaryMethodUI")),
+          h4("6. Summarization",class = "icon-wrapper",icon("question-circle", lib = "font-awesome"),
+             div("Run-level summarization method", class = "icon-tooltip")),
+          p("method: TMP"),
+          p("For linear summarzation please use command line"),
           tags$hr(),
           
           # remove features with more than 50% missing 
